summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-19 23:55:23 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-19 23:55:23 -0600
commit2e9d9798228556f593c176f27d1ab8a44cdbe1b2 (patch)
tree91c9b8ddcd9fce4192e314b5f60b7306a5c7c280
parentd7120b9627571085ef4f12662370d133cbdb3571 (diff)
downloadtdeio-locate-2e9d9798228556f593c176f27d1ab8a44cdbe1b2.tar.gz
tdeio-locate-2e9d9798228556f593c176f27d1ab8a44cdbe1b2.zip
Rename KApplication to TDEApplication to avoid conflicts with KDE4
-rw-r--r--src/kio_locate.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/kio_locate.cpp b/src/kio_locate.cpp
index 47a70eb..d5965e7 100644
--- a/src/kio_locate.cpp
+++ b/src/kio_locate.cpp
@@ -1013,9 +1013,9 @@ extern "C"
{
int kdemain(int argc, char **argv)
{
// We use KApplication instead of KInstance here, because we use a
// config dialog and such gui stuff.
- KApplication app(argc, argv, "kio_locate", false, true);
+ TDEApplication app(argc, argv, "kio_locate", false, true);
DEBUGSTR << "*** Starting kio_locate " << endl;
@@ -1013,9 +1013,9 @@ extern "C"
int kdemain(int argc, char **argv)
{
- // We use KApplication instead of KInstance here, because we use a
+ // We use TDEApplication instead of KInstance here, because we use a
// config dialog and such gui stuff.